@@ -397,7 +397,137 @@ my @ver2func = (
               ^gsl_matrix_uint_scale_columns$
               /
             ]
+    },
+    "2.7" => {
+        new => [
+            qw/
+              ^gsl_vector_sum$
+              ^gsl_vector_char_sum$
+              ^gsl_vector_uchar_sum$
+              ^gsl_vector_int_sum$
+              ^gsl_vector_uint_sum$
+              ^gsl_vector_ushort_sum$
+              ^gsl_vector_long_sum$
+              ^gsl_vector_ulong_sum$
+              ^gsl_vector_long_double_sum$
+              ^gsl_vector_float_sum$
+              ^gsl_matrix_norm1$
+              ^gsl_matrix_int_norm1$
+              ^gsl_matrix_uchar_norm1$
+              ^gsl_matrix_ushort_norm1$
+              ^gsl_matrix_ulong_norm1$
+              ^gsl_matrix_char_norm1$
+              ^gsl_matrix_float_norm1$
+              ^gsl_matrix_short_norm1$
+              ^gsl_matrix_long_double_norm1$
+              ^gsl_matrix_long_norm1$
+              ^gsl_matrix_uint_norm1$
+              ^gsl_matrix_scale_rows$
+              ^gsl_matrix_complex_float_scale_rows$
+              ^gsl_matrix_complex_scale_rows$
+              ^gsl_matrix_uchar_scale_rows$
+              ^gsl_matrix_ushort_scale_rows$
+              ^gsl_matrix_ulong_scale_rows$
+              ^gsl_matrix_char_scale_rows$
+              ^gsl_matrix_float_scale_rows$
+              ^gsl_matrix_short_scale_rows$
+              ^gsl_matrix_complex_long_double_scale_rows$
+              ^gsl_matrix_long_double_scale_rows$
+              ^gsl_matrix_uint_scale_rows$
+              ^gsl_matrix_int_scale_rows$
+              ^gsl_matrix_scale_columns$
+              ^gsl_matrix_complex_scale_columns$
+              ^gsl_matrix_uchar_scale_columns$
+              ^gsl_matrix_ushort_scale_columns$
+              ^gsl_matrix_ulong_scale_columns$
+              ^gsl_matrix_char_scale_columns$
+              ^gsl_matrix_float_scale_columns$
+              ^gsl_matrix_short_scale_columns$
+              ^gsl_matrix_complex_long_double_scale_columns$
+              ^gsl_matrix_long_double_scale_columns$
+              ^gsl_matrix_uint_scale_columns$
+              ^gsl_matrix_int_scale_columns$
+              ^gsl_matrix_complex_conjtrans_memcpy$
+              ^gsl_multifit_linear_lcurvature$
+              ^gsl_spmatrix_dense_add$
+              ^gsl_spmatrix_uint_dense_add$
+              ^gsl_spmatrix_int_dense_add$
+              ^gsl_spmatrix_long_double_dense_add$
+              ^gsl_spmatrix_float_dense_add$
+              ^gsl_spmatrix_long_dense_add$
+              ^gsl_spmatrix_complex_float_dense_add$
+              ^gsl_spmatrix_char_dense_add$
+              ^gsl_spmatrix_uchar_dense_add$
+              ^gsl_spmatrix_ulong_dense_add$
+              ^gsl_spmatrix_short_dense_add$
+              ^gsl_spmatrix_ushort_dense_add$
+              ^gsl_spmatrix_long_double_dense_add$
+              ^gsl_spmatrix_complex_dense_add$
+              ^gsl_spmatrix_complex_long_double_dense_add$
+              ^gsl_spmatrix_dense_sub$
+              ^gsl_spmatrix_uint_dense_sub$
+              ^gsl_spmatrix_int_dense_sub$
+              ^gsl_spmatrix_long_double_dense_sub$
+              ^gsl_spmatrix_float_dense_sub$
+              ^gsl_spmatrix_long_dense_sub$
+              ^gsl_spmatrix_complex_float_dense_sub$
+              ^gsl_spmatrix_char_dense_sub$
+              ^gsl_spmatrix_uchar_dense_sub$
+              ^gsl_spmatrix_ulong_dense_sub$
+              ^gsl_spmatrix_short_dense_sub$
+              ^gsl_spmatrix_ushort_dense_sub$
+              ^gsl_spmatrix_long_double_dense_sub$
+              ^gsl_spmatrix_complex_long_double_dense_sub$
+              ^gsl_spmatrix_complex_dense_sub$
+              ^gsl_spmatrix_norm1
+              ^gsl_spmatrix_int_norm1$
+              ^gsl_spmatrix_float_norm1$
+              ^gsl_spmatrix_long_norm1$
+              ^gsl_spmatrix_char_norm1$
+              ^gsl_spmatrix_ulong_norm1$
+              ^gsl_spmatrix_short_norm1$
+              ^gsl_spmatrix_ushort_norm1$
+              ^gsl_spmatrix_long_double_norm1$
+              ^gsl_spmatrix_uint_norm1$
+              ^gsl_spmatrix_uchar_norm1$
+              ^gsl_linalg_complex_QR_solve_r$
+              ^gsl_linalg_complex_QR_solve$
+              ^gsl_linalg_complex_QR_svx$
+              ^gsl_linalg_complex_QR_decomp$
+              ^gsl_linalg_complex_QR_decomp_r$
+              ^gsl_linalg_complex_QR_lssolve$
+              ^gsl_linalg_complex_QR_lssolve_r$
+              ^gsl_linalg_complex_QR_QHvec$
+              ^gsl_linalg_complex_QR_QHvec_r$
+              ^gsl_linalg_complex_QR_Qvec$
+              ^gsl_linalg_complex_QR_unpack$
+              ^gsl_linalg_complex_QR_unpack_r$
+              ^gsl_linalg_cholesky_band_solvem$
+              ^gsl_linalg_cholesky_band_scale_apply$
+              ^gsl_linalg_cholesky_band_svxm$
+              ^gsl_linalg_cholesky_band_scale$
+              ^gsl_linalg_QR_UU_QTvec$
+              ^gsl_linalg_QR_UU_decomp$
+              ^gsl_linalg_QR_UU_lssolve$
+              ^gsl_linalg_QR_UZ_decomp$
+              ^gsl_linalg_QR_UD_lssolve$
+              ^gsl_linalg_QR_UD_decomp$
+              ^gsl_linalg_QR_UR_decomp$
+              ^gsl_linalg_QR_decomp_old$
+              ^gsl_linalg_QR_band_decomp_L2$
+              ^gsl_linalg_QR_band_unpack_L2$
+              ^gsl_linalg_QL_decomp$
+              ^gsl_linalg_QL_unpack$
+              ^gsl_linalg_LU_band_unpack$
+              ^gsl_linalg_LU_band_svx$
+              ^gsl_linalg_LU_band_decomp$
+              ^gsl_linalg_LU_band_solve$
+              ^gsl_linalg_householder_transform2$
+
+              /
+        ]
     }
+
 );
 
 my ( %index, @info, @versions );
